@@ -13,7 +13,7 @@ class set_build_base_mixin(object):
         """
         try:
             if not self.build_base or self.build_base == 'build':
-                self.build_base = cmaker.SETUPTOOLS_INSTALL_DIR
+                self.build_base = cmaker.SETUPTOOLS_INSTALL_DIR()
         except AttributeError:
             pass
 
