@@ -178,6 +178,7 @@ def initialize_git_repo_and_commit(project_dir, verbose=True):
             ['git', 'init'],
             ['git', 'config', 'user.name', 'scikit-build'],
             ['git', 'config', 'user.email', 'test@test'],
+            ['git', 'config', 'commit.gpgsign', 'false'],
             ['git', 'add', '-A'],
             ['git', 'reset', '.gitignore'],
             ['git', 'commit', '-m', 'Initial commit']
@@ -317,3 +318,12 @@ def list_ancestors(path):
     """Return logical ancestors of the path.
     """
     return [str(parent) for parent in pathlib.PurePosixPath(path).parents if str(parent) != "."]
+
+
+def get_ext_suffix():
+    """Return python extension suffix.
+    """
+    ext_suffix_var = 'SO'
+    if sys.version_info[:2] >= (3, 5):
+        ext_suffix_var = 'EXT_SUFFIX'
+    return distutils.sysconfig.get_config_var(ext_suffix_var)
