@@ -33,7 +33,7 @@ def test_outside_project_root_fails(option):
             expected_failure = True
             cmd.extend(["--", option])
 
-        @project_setup_py_test("fail-outside-project-root", cmd)
+        @project_setup_py_test("fail-outside-project-root", cmd, disable_languages_test=True)
         def should_fail():
             pass
 
