@@ -84,14 +84,15 @@ def test_generator_cleanup():
 
 
 @pytest.mark.parametrize("supported_platform",
-                         ['darwin', 'freebsd', 'linux', 'windows'])
+                         ['darwin', 'freebsd', 'linux', 'windows', 'os400'])
 def test_known_platform(supported_platform, mocker):
     mocker.patch('platform.system', return_value=supported_platform)
     platforms = {
         'freebsd': 'BSD',
         'linux': 'Linux',
         'darwin': 'OSX',
-        'windows': 'Windows'
+        'windows': 'Windows',
+        'os400': 'BSD'
     }
     expected_platform_classname = "%sPlatform" % platforms[supported_platform]
     assert get_platform().__class__.__name__ == expected_platform_classname
